@@ -296,12 +296,33 @@ create_mu_vector <- function(state_names,
 
 #' @keywords internal
 replace_matrix <- function(focal_matrix,
-                           params) {
-  for (i in seq_len(nrow(focal_matrix))) {
-    for (j in seq_len(ncol(focal_matrix))) {
-      if (focal_matrix[i, j] != 0 && !is.na(focal_matrix[i, j]))  {
-        index <- focal_matrix[i, j]
-        focal_matrix[i, j] <- params[index]
+                           params,
+                           is_lambda = FALSE) {
+  if (is_lambda) {
+    entries <- table(focal_matrix)
+    entries <- entries[names(entries) != 0]
+    for (i in seq_len(nrow(focal_matrix))) {
+      for (j in seq_len(ncol(focal_matrix))) {
+        if (focal_matrix[i, j] != 0 && !is.na(focal_matrix[i, j]))  {
+          index <- focal_matrix[i, j]
+          
+          new_val <- params[index]
+          if (index %in% names(entries)) {
+            mult <- 1 / entries[names(entries) == index]
+            new_val <- new_val * mult
+          }
+          
+          focal_matrix[i, j] <- new_val
+        }
+      }
+    }
+  } else {
+    for (i in seq_len(nrow(focal_matrix))) {
+      for (j in seq_len(ncol(focal_matrix))) {
+        if (focal_matrix[i, j] != 0 && !is.na(focal_matrix[i, j]))  {
+          index <- focal_matrix[i, j]
+          focal_matrix[i, j] <- params[index]
+        }
       }
     }
   }
@@ -318,7 +339,7 @@ fill_in <- function(object,
                     params) {
   if (is.list(object)) { # lambda matrix
     for (k in seq_along(object)) {
-      object[[k]] <- replace_matrix(object[[k]], params)
+      object[[k]] <- replace_matrix(object[[k]], params, is_lambda = FALSE)
     }
   } else if (is.matrix(object)) {
     object <- replace_matrix(object, params)
